<template>
  <div class="bbsl-common-page">
    <div class="content">
      <div id="echarts" class="full"></div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import performanceAnalysis from '@/api/device/performanceAnalysis.js'
export default {
  data() {
    return {
      chartData: []
    }
  },
  mounted() {
    this.getStatistics()
    this.initChart()
  },
  methods: {
    //获取设备统计分析
    getStatistics() {
      let productType = 'jwwxyjc'
      performanceAnalysis.deviceType(productType, res => {
        // console.log(res)
        if (res.state) {
          this.chartData = res.value
          this.$nextTick(() => {
            this.initChart()
          })
        }
      })
    },
    initChart() {
      let names = []
      let brower = []
      this.chartData.forEach(item => {
        names.push(item.statusName)
        brower.push({
          name: item.statusName,
          value: item.count
        })
      })
      let chartDom = document.getElementById('echarts')
      //注意此处与全局不同
      let myChart = echarts.init(chartDom)
      let option = {
        title: {
          text: '设备状态统计',
          left: 'center'
        },
        tooltip: {
          trigger: 'item'
        },
        legend: {
          data: this.names,
          orient: 'vertical',
          left: 'right'
        },
        series: [
          {
            name: names,
            type: 'pie',
            radius: '50%',
            data: brower,
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            },
            itemStyle: {
              normal: {
                color: function(colors) {
                  var colorList = [
                    '#ef6567',
                    '#91cd77',
                    '#f9c956',
                    '#5470c6',
                    '#75bedc'
                  ]
                  return colorList[colors.dataIndex]
                }
              }
            }
          }
        ]
      }
      myChart.setOption(option)
      window.addEventListener('resize', () => {
        if (myChart) {
          myChart.resize()
        }
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.content {
  height: 100%;
  padding: 1.04167vw 1.04167vw;
  background-color: #fff;
  box-shadow: 0 0 0.625vw 0;
  position: relative;
}
.full {
  height: calc(100% - 50px);
}
</style>
